<a id="mypy-boto3-voice-id"></a>

# mypy-boto3-voice-id

[![PyPI - mypy-boto3-voice-id](https://img.shields.io/pypi/v/mypy-boto3-voice-id.svg?color=blue)](https://pypi.org/project/mypy-boto3-voice-id)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-voice-id.svg?color=blue)](https://pypi.org/project/mypy-boto3-voice-id)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)
[![PyPI - Downloads](https://img.shields.io/pypi/dw/mypy-boto3-voice-id?color=blue)](https://pypistats.org/packages/mypy-boto3-voice-id)

![boto3.typed](https://github.com/vemel/mypy_boto3_builder/raw/master/logo.png)

Type annotations for
[boto3.VoiceID 1.18.57](https://boto3.amazonaws.com/v1/documentation/api/1.18.57/reference/services/voice-id.html#VoiceID)
service compatible with [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright) and other tools.

Generated by
[mypy-boto3-builder 5.5.0](https://github.com/vemel/mypy_boto3_builder).

More information can be found on
[boto3-stubs](https://pypi.org/project/boto3-stubs/) page and in
[mypy-boto3-voice-id docs](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_voice_id/)

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/vemel/mypy_boto3_builder/raw/master/demo.gif)

- [mypy-boto3-voice-id](#mypy-boto3-voice-id)
  - [How to install](#how-to-install)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Literals](#literals)
    - [Typed dictionaries](#typed-dictionaries)
  - [Versioning](#versioning)
  - [Documentation](#documentation)
  - [Support and contributing](#support-and-contributing)

<a id="how-to-install"></a>

## How to install

Install `boto3-stubs` for `VoiceID` service.

```bash
python -m pip install boto3-stubs[voice-id]
```

<a id="usage"></a>

## Usage

<a id="vscode"></a>

### VSCode

- Install
  [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install
  [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `boto-stubs[voice-id]` in your environment:
  `python -m pip install 'boto3-stubs[voice-id]'`

Both type checking and auto-complete should work for `VoiceID` service. No
explicit type annotations required, write your `boto3` code as usual.

<a id="pycharm"></a>

### PyCharm

- Install `boto-stubs[voice-id]` in your environment:
  `python -m pip install 'boto3-stubs[voice-id]'`

Both type checking and auto-complete should work for `VoiceID` service. No
explicit type annotations required, write your `boto3` code as usual.
Auto-complete can be slow on big projects or if you have a lot of installed
`boto3-stubs` submodules.

<a id="other-ides"></a>

### Other IDEs

Not tested, but as long as your IDE supports `mypy` or `pyright`, everything
should work.

<a id="mypy"></a>

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `boto-stubs[voice-id]` in your environment:
  `python -m pip install 'boto3-stubs[voice-id]'`
- Run `mypy` as usual

Type checking should work for `VoiceID` service. No explicit type annotations
required, write your `boto3` code as usual.

<a id="pyright"></a>

### pyright

- Install `pyright`: `yarn global add pyright`
- Install `boto-stubs[voice-id]` in your environment:
  `python -m pip install 'boto3-stubs[voice-id]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `VoiceID` service. No explicit type annotations
required, write your `boto3` code as usual.

<a id="explicit-type-annotations"></a>

## Explicit type annotations

<a id="client-annotations"></a>

### Client annotations

`VoiceIDClient` provides annotations for `boto3.client("voice-id")`.

```python
import boto3

from mypy_boto3_voice_id import VoiceIDClient

client: VoiceIDClient = boto3.client("voice-id")

# now client usage is checked by mypy and IDE should provide code auto-complete

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: VoiceIDClient = session.client("voice-id")
```

<a id="literals"></a>

### Literals

`mypy_boto3_voice_id.literals` module contains literals extracted from shapes
that can be used in user code for type checking.

```python
from mypy_boto3_voice_id.literals import (
    AuthenticationDecisionType,
    DomainStatusType,
    DuplicateRegistrationActionType,
    ExistingEnrollmentActionType,
    FraudDetectionActionType,
    FraudDetectionDecisionType,
    FraudDetectionReasonType,
    FraudsterRegistrationJobStatusType,
    SpeakerEnrollmentJobStatusType,
    SpeakerStatusType,
    StreamingStatusType,
    ServiceName,
)

def check_value(value: AuthenticationDecisionType) -> bool:
    ...
```

<a id="typed-dictionaries"></a>

### Typed dictionaries

`mypy_boto3_voice_id.type_defs` module contains structures and shapes assembled
to typed dictionaries for additional type checking.

```python
from mypy_boto3_voice_id.type_defs import (
    AuthenticationConfigurationTypeDef,
    AuthenticationResultTypeDef,
    CreateDomainRequestRequestTypeDef,
    CreateDomainResponseTypeDef,
    DeleteDomainRequestRequestTypeDef,
    DeleteFraudsterRequestRequestTypeDef,
    DeleteSpeakerRequestRequestTypeDef,
    DescribeDomainRequestRequestTypeDef,
    DescribeDomainResponseTypeDef,
    DescribeFraudsterRegistrationJobRequestRequestTypeDef,
    DescribeFraudsterRegistrationJobResponseTypeDef,
    DescribeFraudsterRequestRequestTypeDef,
    DescribeFraudsterResponseTypeDef,
    DescribeSpeakerEnrollmentJobRequestRequestTypeDef,
    DescribeSpeakerEnrollmentJobResponseTypeDef,
    DescribeSpeakerRequestRequestTypeDef,
    DescribeSpeakerResponseTypeDef,
    DomainSummaryTypeDef,
    DomainTypeDef,
    EnrollmentConfigTypeDef,
    EnrollmentJobFraudDetectionConfigTypeDef,
    EvaluateSessionRequestRequestTypeDef,
    EvaluateSessionResponseTypeDef,
    FailureDetailsTypeDef,
    FraudDetectionConfigurationTypeDef,
    FraudDetectionResultTypeDef,
    FraudRiskDetailsTypeDef,
    FraudsterRegistrationJobSummaryTypeDef,
    FraudsterRegistrationJobTypeDef,
    FraudsterTypeDef,
    InputDataConfigTypeDef,
    JobProgressTypeDef,
    KnownFraudsterRiskTypeDef,
    ListDomainsRequestRequestTypeDef,
    ListDomainsResponseTypeDef,
    ListFraudsterRegistrationJobsRequestRequestTypeDef,
    ListFraudsterRegistrationJobsResponseTypeDef,
    ListSpeakerEnrollmentJobsRequestRequestTypeDef,
    ListSpeakerEnrollmentJobsResponseTypeDef,
    ListSpeakersRequestRequestTypeDef,
    ListSpeakersResponseTypeDef,
    ListTagsForResourceRequestRequestTypeDef,
    ListTagsForResourceResponseTypeDef,
    OptOutSpeakerRequestRequestTypeDef,
    OptOutSpeakerResponseTypeDef,
    OutputDataConfigTypeDef,
    RegistrationConfigTypeDef,
    ResponseMetadataTypeDef,
    ServerSideEncryptionConfigurationTypeDef,
    SpeakerEnrollmentJobSummaryTypeDef,
    SpeakerEnrollmentJobTypeDef,
    SpeakerSummaryTypeDef,
    SpeakerTypeDef,
    StartFraudsterRegistrationJobRequestRequestTypeDef,
    StartFraudsterRegistrationJobResponseTypeDef,
    StartSpeakerEnrollmentJobRequestRequestTypeDef,
    StartSpeakerEnrollmentJobResponseTypeDef,
    TagResourceRequestRequestTypeDef,
    TagTypeDef,
    UntagResourceRequestRequestTypeDef,
    UpdateDomainRequestRequestTypeDef,
    UpdateDomainResponseTypeDef,
)

def get_structure() -> AuthenticationConfigurationTypeDef:
    return {
      ...
    }
```

<a id="versioning"></a>

## Versioning

`mypy-boto3-voice-id` version is the same as related `boto3` version and
follows [PEP 440](https://www.python.org/dev/peps/pep-0440/) format.

<a id="documentation"></a>

## Documentation

All type annotations can be found in
[mypy-boto3-voice-id docs](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_voice_id/)

<a id="support-and-contributing"></a>

## Support and contributing

This package is auto-generated. Please reports any bugs or request new features
in [mypy-boto3-builder](https://github.com/vemel/mypy_boto3_builder/issues/)
repository.
